//*******************************************************************************
//  MSP-FET430F16x - Trace
//
//  Description;  This demo shows how the State Storage 
//  can be used for an instruction trace to see that last 
//  eight instructions the CPU has executed
//
//
//  Setup Trace Storage:
//  - open the State Storage Control menu (Window | Show View | Trace)
//    - open the properties window
//    - Select: Start on immediately and stop when buffer full
//    - Select: Instruction Fetch            
//  - Select: Restart Automatically when finished
//  - Start Trace
//
//  Execute the Program -> Go
//  Stop the Program -> Halt
//  -> The State Storage window displays the last 8 instructions
//     which have been executed by the CPU
// 
//  Note: Try this with Example 2, to see where the function which causes
//        the stack overflow was called.
//
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (169)
//            |             P5.1|-->LED (449)
//
//
//  S. Schauer
//  Texas Instruments, Inc
//  April 2008
//  Built with CCE V3.0
//
//
//******************************************************************************


#include  <msp430f5438a.h>

#define TRUE  (1==1)
#define FALSE (!TRUE)

// Variable Defintions

volatile unsigned int wLoopCounter = 0;     // Processing loop counter

// Function Prototypes
void Delay(unsigned int Value);

void main(void)
{

  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  P1OUT  = 0x00;                            // init output
  P1DIR |= 0x01;                            // Set P1.0 to output direction
  P5OUT  = 0x00;                            // init output
  P5DIR |= 0x02;                            // Set P5.1 to output direction
  
 
  _EINT();                                  // Enable interrupts
  
  while(TRUE)
  {
    wLoopCounter++;
    P1OUT ^= 0x01;                          // Toggle P1.0 using exclusive-OR
    P5OUT ^= 0x02;                          // Toggle P5.1 using exclusive-OR
    Delay(10000);
  }
}

void Delay(unsigned int Value)
{
  volatile unsigned int j = 0;
   
  for(j=Value; j>0; j--);
}
