//*******************************************************************************
//  MSP-FET430F16x - Breakpoint on Variable write
//
//  Description; This demo shows how a breakpoint can be set to a certain 
//  Variable.
//
//  Setup Breakpoint:
//  - open the Breapoint menu (Window | Show View | Breakpoints)
//  - click drop down menu for new Breakpoint and select Watchpoint
//    - Location: &wLoopCounter
//    - Access Type: Write
//    Close the dialog by clicking OK and execute the program
//    -> Run
//    -> the CPU will stop on the first write access to the
//       variable wLoopCounter
//
//  Setup Breakpoint to stop on a write of a certain value to the variable: 
//  Setup Breakpoint:
//  - click drop down menu for new Breakpoint and select Watchpoint with Data
//    - Location: &wLoopCounter
//    - Data Value:  50
//    - Access Type: Write
//  - or modify the previously set breakpoint (right click on breakpoint | Properties...):
//    - set Trigger 1: Memory Data Bus: 50
//      - Operator:    ==
//      - Access Type: Write
//    Close the dialog by clicking OK, Reset the program and execute the program
//    -> Run
//    -> the CPU will stop after the value 50 has been written to the
//       Variable wLoopCounter
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (169)
//            |             P5.1|-->LED (449)
//
//
//  S. Schauer
//  Texas Instruments, Inc
//  April 2008
//  Built with CCE V3.0
//
//
//******************************************************************************


#include  <msp430f5529.h>

#define TRUE  (1==1)
#define FALSE (!TRUE)

// Variable Defintions

volatile unsigned int wLoopCounter = 0;     // Processing Loop Counter

// Function Prototypes
void Delay(unsigned int Value);

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  P1OUT  = 0x00;                            // init output
  P1DIR |= 0x01;                            // Set P1.0 to output direction
  P5OUT  = 0x00;                            // init output
  P5DIR |= 0x02;                            // Set P5.1 to output direction
  
 
  _EINT();                                  // Enable interrupts
  
  while(TRUE)
  {
    wLoopCounter++;
    P1OUT ^= 0x01;                          // Toggle P1.0 using exclusive-OR
    P5OUT ^= 0x02;                          // Toggle P5.1 using exclusive-OR
    Delay(10000);
  }
}

void Delay(unsigned int Value)
{
  volatile unsigned int j = 0;
   
  for(j=Value; j>0; j--);
}
