//*******************************************************************************
//  MSP-FET430F16x - Test for Stack Overflow
//
//  Description; After a delay the function 'DummyStackFill' is called 
//  which places 100 Bytes on the Stack
//
//  Setup Breakpoint:
//  - open the Breapoint menu (Window | Show View | Breakpoints)
//  - click drop down menu for new Breakpoint and select Break on Stack Overflow
//    - Stack Min: &_stack  (is the minimum Stack as set in the project settings)
//    Close the dialog by clicking OK and execute the program
//    -> Run
//    -> the CPU will stop when the function 'DummyStackFill' is called
//       because during the intialisation 100 words are pushed 
//       to the Stack and the Stackpointer will go below the set value of the Stack size
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (169)
//            |             P5.1|-->LED (449)
//
//
//  S. Schauer
//  Texas Instruments, Inc
//  April 2008
//  Built with CCE V3.0
//
//******************************************************************************


#include  <msp430f5529.h>

#define TRUE  (1==1)
#define FALSE (!TRUE)

// Variable Defintions

volatile unsigned int wLoopCounter = 0;     // Processing loop counter

// Function Prototypes
void Delay(unsigned int Value);

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  P1OUT  = 0x00;                            // init output
  P1DIR |= 0x01;                            // Set P1.0 to output direction
  P5OUT  = 0x00;                            // init output
  P5DIR |= 0x02;                            // Set P5.1 to output direction
  
  TB0CTL = TASSEL_2 + MC_1;                  // Run to CCR0 with SMCLK
  TB0CCR0 = 1000;                            //
  TB0CCTL0 = CCIE;                           // Enable CCR0 int.

  _EINT();                                  // Enable interrupts
  
  while(TRUE)
  {
    wLoopCounter++;
    P1OUT ^= 0x01;                          // Toggle P1.0 using exclusive-OR
    P5OUT ^= 0x02;                          // Toggle P5.1 using exclusive-OR
    Delay(10000);
  }
}

void Delay(unsigned int Value)
{
  volatile unsigned int j = 0;
   
  for(j=Value; j>0; j--);
}


void DummyStackFill(void)
{
  volatile unsigned int k[100]=0;           // Local Variable is stored on the stack
                                            // -> 100 words are pushed to the stack
}


#pragma vector=TIMERB0_VECTOR
__interrupt void isr_TB0CCR0()
{
  static   unsigned int j=0;                // Entrance counter
  j++;
  if (j>5000)
  {
    DummyStackFill();
    j = 0; 
  }
}

