//*******************************************************************************
//  MSP-FET430F16x - Breakpoint on write access to Flash
//
//  Description;  This demo shows how a breakpoint can be set 
//  to stop the program execution if the program tries to write 
//  data to the flash.
//
//  Setup Breakpoint:
//  - open the Breapoint menu (Window | Show View | Breakpoints)
//  - click drop down menu for new Breakpoint and select Watchpoint on Data Address Range
//    - Range Start: 0x1100 (Start of Main Flash Memory)
//    - Range End:   0xFFFF
//    - Access Type : Write
//    Close the dialog by clicking OK and execute the program 
//    -> Run
//    -> the CPU will stop after the first write access to the
//       Flash ( = '(*pwDataInFlash)++' instruction)
//
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (169)
//            |             P5.1|-->LED (449)
//
//
//  S. Schauer
//  Texas Instruments, Inc
//  April 2008
//  Built with CCE V3.0
//
//
//******************************************************************************


#include  <msp430f5529.h>

#define TRUE  (1==1)
#define FALSE (!TRUE)

// Variable Defintions

volatile unsigned int wLoopCounter = 0;     // Processing loop counter

const unsigned int wDataInFlash = 0;        // locate in Flash
unsigned int * pwDataInFlash;
unsigned int temp;

#define BSL_START    0x1000

// Function Prototypes
void Delay(unsigned int Value);

void main(void)
{
  unsigned int i = 0;
  pwDataInFlash = (unsigned int*)&wDataInFlash;

  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  P1OUT  = 0x00;                            // init output
  P1DIR |= 0x01;                            // Set P1.0 to output direction
  P5OUT  = 0x00;                            // init output
  P5DIR |= 0x02;                            // Set P5.1 to output direction
  
 
  _EINT();                                  // Enable interrupts
  
  while(TRUE)
  {
    wLoopCounter++;
    P1OUT ^= 0x01;                          // Toggle P1.0 using exclusive-OR
    P5OUT ^= 0x02;                          // Toggle P5.1 using exclusive-OR
    Delay(10000);
    i++;
    if ( i == 50)
    {
      (*pwDataInFlash)++;                   // this should create a break - no write in Flash allowed
      _NOP();                               // This NOP is used to show that it really was '(*pwDataInFlash)++;'
                                            // that caused the break - PC stops here
    }
    if ( i == 100)
    {
      i = 0;
      temp = (*(unsigned int *)BSL_START);  // this should create a break - no read from ROM allowed
      _NOP();                               // This NOP is used to show that it really was '(temp = (*0x1000);'
                                            // that caused the break - PC stops here
    }
  }
}

#pragma CODE_SECTION(Delay,".infoB")
void Delay(unsigned int Value)
{
  volatile unsigned int j = 0;
   
  for(j=Value; j>0; j--);
}

