//*******************************************************************************
//  MSP-FET430F16x - Trace on Variable write
//
//  Description; This demo shows how a variable can 
//  be watched in real time, without stoppping the CPU.
//
//  Setup Breakpoint / Trigger:
//  Setup Breakpoint:
//  - click drop down menu for new Breakpoint and select Watchpoint
//    - Location: &wLoopCounter
//    - Access Type: Write
//  - Modify the previously set breakpoint (right click on breakpoint | Properties...):
//    - Action : Trigger Storage
//    Other fields: unchanged           
//    Close the dialog with OK 
//
//  Setup Trace Storage:
//  - open the State Storage Control menu (Window | Show View | Trace)
//    - open the properties window
//    - Select: Store on Trigger and stop when buffer full
//    - Select: Restart Automatically
//  - Start Trace
//
//  Execute the Program -> Go
//  Open the State Storage Window (Emulator | State Storage Window)    
//  -> the Trace Buffer inside the MSP430 is read and display
//  -> the information written to the variable wLoopCounter
//     could be displayed without stopping or influencing the program
//     execution
// 
//                   MSP430
//             -----------------
//         /|\|              XIN|-  
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED
//
//
//  S. Schauer
//  Texas Instruments, Inc
//  April 2008
//  Built with CCE V3.0
//
//******************************************************************************


#include  <msp430f5529.h>

#define TRUE  (1==1)
#define FALSE (!TRUE)

// Variable Defintions

volatile unsigned int wLoopCounter = 0;     // Processing loop counter

// Function Prototypes
void Delay(unsigned int Value);

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  P1OUT  = 0x00;                            // init output
  P1DIR |= 0x01;                            // Set P1.0 to output direction
  P5OUT  = 0x00;                            // init output
  P5DIR |= 0x02;                            // Set P5.1 to output direction
  
 
  _EINT();                                  // Enable interrupts
  
  while(TRUE)
  {
    wLoopCounter++;
    P1OUT ^= 0x01;                          // Toggle P1.0 using exclusive-OR
    P5OUT ^= 0x02;                          // Toggle P5.1 using exclusive-OR
    Delay(10000);
  }
}

void Delay(unsigned int Value)
{
  volatile unsigned int j = 0;
   
  for(j=Value; j>0; j--);
}
